@@ -44,17 +44,23 @@ from internetarchive.iacli.argparser import get_args_dict, get_xml_text
 
 # main()
 #_________________________________________________________________________________________
-def _upload_files(args, identifier, local_file, upload_kwargs):
+def _upload_files(args, identifier, local_file, upload_kwargs, prev_identifier=None):
     verbose = True if args['--quiet'] is False else False
     config = {} if not args['--log'] else {'logging': {'level': 'INFO'}}
     item = get_item(identifier, config=config)
-    if verbose:
+    if (verbose) and (prev_identifier != identifier):
         sys.stdout.write('{0}:\n'.format(item.identifier))
 
     try:
-        response = item.upload(local_file, **upload_kwargs)
+        if args['--remote-name']:
+            files = {args['--remote-name']: local_file}
+        else:
+            files = local_file
+        response = item.upload(files, **upload_kwargs)
     except HTTPError as exc:
         response = [exc.response]
+        if not response[0]:
+            sys.exit(1)
         if response[0].status_code == 403:
             if (not item.session.access_key) and (not item.session.secret_key):
                 sys.stderr.write('\nIAS3 Authentication failed. Please set your IAS3 '
@@ -127,18 +133,26 @@ def main(argv):
         local_file = TemporaryFile()
         local_file.write(sys.stdin.read())
         local_file.seek(0)
-        upload_kwargs['key'] = args['--remote-name']
         _upload_files(args, args['<identifier>'], local_file, upload_kwargs)
 
     # Bulk upload using spreadsheet.
     elif args['--spreadsheet']:
         spreadsheet = csv.DictReader(open(args['--spreadsheet'], 'rU'))
+        prev_identifier = None
         for row in spreadsheet:
             local_file = row['file']
+            identifier = row['item']
             del row['file']
-            metadata = dict((k.lower(), v) for (k, v) in row.items() if v)
+            del row['item']
+            if (not identifier) and (prev_identifier):
+                identifier = prev_identifier
+            # TODO: Clean up how indexed metadata items are coerced
+            # into metadata.
+            md_args = ['{0}:{1}'.format(k.lower(), v) for (k, v) in row.items() if v]
+            metadata = get_args_dict(md_args)
             upload_kwargs['metadata'].update(metadata)
-            _upload_files(args, row['item'], local_file, upload_kwargs)
+            _upload_files(args, identifier, local_file, upload_kwargs, prev_identifier)
+            prev_identifier = identifier
 
     # Upload files.
     else:
